<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ru">
<context>
    <name>About</name>
    <message>
        <location filename="../components/About.qml" line="9"/>
        <source>About</source>
        <translation>О проекте</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="80"/>
        <source>&lt;p&gt;This service is paid for entirely by donations from users like you. &lt;a href=&quot;%1&quot;&gt;Please donate&lt;/a&gt;.&lt;/p&gt;</source>
        <extracomment>donation text of the about dialog</extracomment>
        <translation>&lt;p&gt;Этот сервис полностью оплачивается за счет пожертвований таких пользователей, как вы. &lt;a href=&quot;%1&quot;&gt;Пожалуйста, сделайте пожертвование&lt;/a&gt;.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="../components/About.qml" line="103"/>
        <source>%1 version: 
%2</source>
        <extracomment>screenshot https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/screenshots/about.png %1 -&gt; application name %2 -&gt; version string</extracomment>
        <translation>Версия %1: 
%2</translation>
    </message>
</context>
<context>
    <name>Footer</name>
    <message>
        <location filename="../components/Footer.qml" line="180"/>
        <source>Recommended</source>
        <translation>Рекомендовано</translation>
    </message>
</context>
<context>
    <name>Help</name>
    <message>
        <location filename="../components/Help.qml" line="7"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="20"/>
        <source>Troubleshooting and support</source>
        <translation>Решение проблем и поддержка</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="31"/>
        <source>Report a bug</source>
        <translation>Сообщить об ошибке</translation>
    </message>
    <message>
        <location filename="../components/Help.qml" line="42"/>
        <source>How to uninstall</source>
        <translation>Как удалить</translation>
    </message>
</context>
<context>
    <name>InitErrors</name>
    <message>
        <location filename="../components/InitErrors.qml" line="31"/>
        <source>Could not find helpers. Please check your installation</source>
        <translation>Не удалось найти помощников. Пожалуйста, проверьте вашу установку</translation>
    </message>
    <message>
        <location filename="../components/InitErrors.qml" line="44"/>
        <source>Could not find polkit agent.</source>
        <translation>Не удалось найти агент polkit.</translation>
    </message>
</context>
<context>
    <name>Locations</name>
    <message>
        <location filename="../components/Locations.qml" line="21"/>
        <source>Select Location</source>
        <translation>Выбор локации</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="27"/>
        <source>Automatically use best connection</source>
        <extracomment>this is in the radio button for the auto selection</extracomment>
        <translation>Автоматически использовать лучшее соединение</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="29"/>
        <source>Manually select</source>
        <extracomment>Location Selection: label for radio buttons that selects manually</extracomment>
        <translation>Выбор вручную</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="31"/>
        <source>Switching gateway…</source>
        <extracomment>A little display to signal that the clicked gateway is being switched to</extracomment>
        <translation>Переключение шлюза…</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="33"/>
        <source>Only locations with bridges</source>
        <extracomment>Subtitle to explain that only bridge locations are shown in the selector</extracomment>
        <translation>Только локации с мостами</translation>
    </message>
    <message>
        <location filename="../components/Locations.qml" line="65"/>
        <source>Recommended</source>
        <extracomment>Location Selection: label for radio button that selects automatically</extracomment>
        <translation>Рекомендовано</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../components/MainView.qml" line="43"/>
        <location filename="../components/MainView.qml" line="66"/>
        <source>Donate</source>
        <translation>Пожертвовать</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="59"/>
        <source>Preferences</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="73"/>
        <source>Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="80"/>
        <source>About</source>
        <translation>О проекте</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="87"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="111"/>
        <source>Please donate!</source>
        <translation>Пожалуйста, пожертвуйте!</translation>
    </message>
    <message>
        <location filename="../components/MainView.qml" line="125"/>
        <source>This service is paid for entirely by donations from users like you. The cost of running the VPN is approximately 5 USD per person every month, but every little bit counts. Do you want to donate now?</source>
        <translation>Этот сервис полностью оплачивается за счет пожертвований таких пользователей, как вы. Стоимость использования VPN составляет примерно 5 долларов США на человека в месяц, но важен каждый цент. Вы хотите сделать пожертвование прямо сейчас?</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../components/Preferences.qml" line="11"/>
        <source>Preferences</source>
        <translation>Предпочтения</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="55"/>
        <source>Turn off the VPN to make changes</source>
        <translation>Отключите VPN, чтобы внести изменения</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="71"/>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="105"/>
        <source>Censorship circumvention</source>
        <translation>Обход цензуры</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="113"/>
        <source>These techniques can bypass censorship, but are slower. Use them only when needed.</source>
        <translation>Эти методы позволяют обойти цензуру, но работают медленнее. Используйте их только при необходимости.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="127"/>
        <source>Use obfs4 bridges</source>
        <translation>Использовать мосты obfs4</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="153"/>
        <source>Traffic is obfuscated to bypass blocks</source>
        <translation>Трафик обфусцирован для обхода блокировок</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="167"/>
        <source>Use Snowflake</source>
        <translation>Использовать Snowflake</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="182"/>
        <source>Snowflake needs Tor installed in your system</source>
        <translation>Snowflake нуждается в установке Tor в вашей системе</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="195"/>
        <source>Transport</source>
        <translation>Транспорт</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="203"/>
        <source>UDP can make the VPN faster. It might be blocked on some networks.</source>
        <translation>UDP может ускорить VPN. В некоторых сетях UDP блокируется.</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="216"/>
        <source>Use UDP if available</source>
        <translation>Использовать UDP, если доступно</translation>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="231"/>
        <source>KCP might work when UDP is blocked on some networks.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../components/Preferences.qml" line="244"/>
        <source>Use KCP if available</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Splash</name>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>There is a newer version available. </source>
        <translation>Доступна новая версия.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="101"/>
        <source>Make sure to &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;uninstall&lt;/a&gt; the previous one before running the new installer.</source>
        <translation>Перед запуском новой установки обязательно &lt;a href=&quot;https://0xacab.org/leap/bitmask-vpn/-/blob/main/docs/uninstall.md&quot;&gt;удалите&lt;/a&gt; предыдущую.</translation>
    </message>
    <message>
        <location filename="../components/Splash.qml" line="105"/>
        <source>UPGRADE NOW</source>
        <translation>ОБНОВИТЬСЯ СЕЙЧАС</translation>
    </message>
</context>
<context>
    <name>StatusBox</name>
    <message>
        <location filename="../components/StatusBox.qml" line="78"/>
        <source>This can take several minutes</source>
        <translation>Это может занять несколько минут</translation>
    </message>
</context>
<context>
    <name>Systray</name>
    <message>
        <location filename="../components/Systray.qml" line="16"/>
        <source>Checking status…</source>
        <translation>Проверка статуса…</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="36"/>
        <source>Donate</source>
        <translation>Пожертвуйте</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Hide</source>
        <extracomment>Part of the systray menu; show or hide the main app window</extracomment>
        <translation>Скрыть</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="45"/>
        <source>Show</source>
        <translation>Показать</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="57"/>
        <source>Quit</source>
        <extracomment>Part of the systray menu; quits the application</extracomment>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="74"/>
        <source>Connect to</source>
        <translation>Подключиться к</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="76"/>
        <source>Connect</source>
        <translation>Подключить</translation>
    </message>
    <message>
        <location filename="../components/Systray.qml" line="79"/>
        <source>Disconnect</source>
        <translation>Отключить</translation>
    </message>
</context>
<context>
    <name>VPNState</name>
    <message>
        <location filename="../components/VPNState.qml" line="26"/>
        <source>Setting up</source>
        <translation>Настройка</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="51"/>
        <location filename="../components/VPNState.qml" line="153"/>
        <source>Connecting</source>
        <translation>Подключение</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="82"/>
        <source>Unsecured
Connection</source>
        <translation>Соединение 
не защищено</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="117"/>
        <source>Secured
Connection</source>
        <translation>Защищенное
Соединение</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>%1 off</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 выключено</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="265"/>
        <source>off</source>
        <translation>выключено</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="268"/>
        <source>%1 on</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 включено</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="271"/>
        <source>Connecting to %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Подключение к %1</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="274"/>
        <source>Stopping %1</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>Остановка %1</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="277"/>
        <source>%1 blocking internet</source>
        <extracomment>%1 -&gt; application name</extracomment>
        <translation>%1 блокирует интернет</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="284"/>
        <source>pluggable transport connection</source>
        <translation>подключаемое транспортное соединение</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="286"/>
        <source>connection done</source>
        <translation>соединение выполнено</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="288"/>
        <source>doing handshake</source>
        <translation>выполняется рукопожатие</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="290"/>
        <source>handshake done</source>
        <translation>рукопожатие выполнено</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="292"/>
        <source>creating one-hop connection</source>
        <translation>создание одношагового соединения</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="294"/>
        <source>requesting status</source>
        <translation>статус запроса</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="296"/>
        <source>loading status</source>
        <translation>статус загрузки</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="298"/>
        <source>loading keys</source>
        <translation>загрузка ключей</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="300"/>
        <source>requesting descriptors</source>
        <translation>запрос дескрипторов</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="302"/>
        <source>loading descriptors</source>
        <translation>загрузка дескрипторов</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="304"/>
        <source>creating circuit</source>
        <translation>создание цепочки</translation>
    </message>
    <message>
        <location filename="../components/VPNState.qml" line="306"/>
        <source>done</source>
        <translation>выполнено</translation>
    </message>
</context>
<context>
    <name>VPNSwitch</name>
    <message>
        <location filename="../qml/VPNSwitch.qml" line="10"/>
        <source/>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="140"/>
        <source>: a fast and secure VPN. Powered by Bitmask.</source>
        <translation>: быстрый и безопасный VPN. При поддержке Bitmask.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="147"/>
        <source>Do not show the systray icon (useful together with Gnome Shell extension, or to control VPN by other means).</source>
        <translation>Не показывать значок в системном трее (полезно при использовании расширения Gnome Shell или для управления VPN другими способами).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="154"/>
        <source>Enable Web API.</source>
        <translation>Включить Web API.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="160"/>
        <source>Install helpers (Linux only, requires sudo).</source>
        <translation>Установить помощники (только для Linux, требуется sudo).</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="166"/>
        <source>Use obfs4 to obfuscate the traffic, if available in the provider.</source>
        <translation>Для обфускации трафика использовать obfs4, если он доступен у провайдера.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="172"/>
        <source>Enable autostart.</source>
        <translation>Включить автозапуск.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="177"/>
        <source>Web API port (default: 8080)</source>
        <translation>Порт Web API (по умолчанию: 8080)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="180"/>
        <source>Start the VPN, either &apos;on&apos; or &apos;off&apos;.</source>
        <translation>Запуск VPN, или &quot;вкл.&quot; или &quot;выкл.&quot;.</translation>
    </message>
</context>
</TS>